@@ -7,8 +7,8 @@
  */
 #pragma once
 
-#include "types.h"
 #include "kgapidrive_export.h"
+#include "types.h"
 
 #include <QString>
 #include <QUrl>
@@ -25,36 +25,39 @@ namespace Drive
  */
 class KGAPIDRIVE_EXPORT User
 {
-  public:
+public:
     explicit User(const User &other);
     virtual ~User();
     bool operator==(const User &other) const;
-    bool operator!=(const User &other) const { return !operator==(other); }
+    bool operator!=(const User &other) const
+    {
+        return !operator==(other);
+    }
 
     /**
      * @brief Returns a plain text displayable name for this user.
      */
-    QString displayName() const;
+    [[nodiscard]] QString displayName() const;
 
     /**
      * @brief Returns a URL that points to a profile picture of this user.
      */
-    QUrl pictureUrl() const;
+    [[nodiscard]] QUrl pictureUrl() const;
 
     /**
      * @brief Returns whether this user is the same as the authenticated
      *        user for whom the request was made.
      */
-    bool isAuthenticatedUser() const;
+    [[nodiscard]] bool isAuthenticatedUser() const;
 
     /**
      * @brief Returns the user's ID as visible in the permissions collection.
      */
-    QString permissionId() const;
+    [[nodiscard]] QString permissionId() const;
 
     static UserPtr fromJSON(const QVariantMap &jsonMap);
 
-  private:
+private:
     explicit User();
 
     class Private;
@@ -65,4 +68,3 @@ class KGAPIDRIVE_EXPORT User
 } // namespace Drive
 
 } // namespace KGAPI2
-
